# Modeling SAP ERP 6.0
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60#overview)
  * [General Guidelines for Modeling SAP ERP 6.0](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60#general-guidelines-for-modeling-sap-erp-6.0)
  * [Modeling SAP Product Versions, Software Components, Technical Components, and Interfaces](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60#modeling-sap-product-versions,-software-components,-technical-components,-and-interfaces)
  * [Modeling Instances of Systems](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60#modeling-instances-of-systems)


Learn key approaches for modeling SAP ERP 6.0, including product versions, software components, technical components, and interfaces, as well as modeling system instances, such as local customizations.
